==> ksystemlog_4.13.0.orig.tar.xz: ksystemlog-4.13.0/src/tabLogManager.h <==
/***************************************************************************
 *   KSystemLog, a system log viewer tool                                  *
 *   Copyright (C) 2007 by Nicolas Ternisien                               *
 *   nicolas.ternisien@gmail.com                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/

#ifndef _TAB_LOG_MANAGER_H_
#define _TAB_LOG_MANAGER_H_


#include <QObject>

class QString;

class LogManager;


class TabLogManagerPrivate;

/**
 * Class that wrap a LogManager inside a tabbed view
 */
class TabLogManager : public QObject {
	
	Q_OBJECT
	
public:
	TabLogManager(LogManager* logManager);
	
	virtual ~TabLogManager();
	
	LogManager* logManager();
	
	void addNewLinesCount(int newLines);
	void initNewLinesCount();
	
	QString title();
	
private:
	QString logModeName();
	
	TabLogManagerPrivate* const d;
	
};


#endif // _TAB_LOG_MANAGER_H_

==> ksystemlog_16.08.3.orig.tar.xz: ksystemlog-16.08.3/src/tabLogManager.h <==
/***************************************************************************
 *   KSystemLog, a system log viewer tool                                  *
 *   Copyright (C) 2007 by Nicolas Ternisien                               *
 *   nicolas.ternisien@gmail.com                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/

#ifndef _TAB_LOG_MANAGER_H_
#define _TAB_LOG_MANAGER_H_

#include <QObject>

class QString;

class LogManager;

class TabLogManagerPrivate;

/**
 * Class that wrap a LogManager inside a tabbed view
 */
class TabLogManager : public QObject
{
    Q_OBJECT

public:
    TabLogManager(LogManager *logManager);

    virtual ~TabLogManager();

    LogManager *logManager();

    void addNewLinesCount(int newLines);
    void initNewLinesCount();

    QString title();

private:
    QString logModeName();

    TabLogManagerPrivate *const d;
};

#endif // _TAB_LOG_MANAGER_H_
